<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package WordPress
 * @subpackage Twenty_Ten
 * @since Twenty Ten 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'twentyten' ), max( $paged, $page ) );

	?></title>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
<?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>
<script type="text/javascript" src="<?php bloginfo( 'template_directory' ); ?>/jquery-1.6.2.min.js"></script>
</head>

<body <?php body_class(); ?>>
<div id="wrapper" class="hfeed">
	<div id="header">
		<div id="masthead">

<table width="100%" border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="tl"></td>
    <td class="tm"></td>
    <td class="tr"></td>
  </tr>
  <tr>
    <td class="ml"></td>
    <td>
  <table width="100%" border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td class="midm">
    <?php $heading_tag = ( is_home() || is_front_page() ) ? 'h1' : 'div'; ?>
				<<?php echo $heading_tag; ?> id="site-title">
					<span>
						<a href="<?php echo home_url( '/' ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>
					</span>
				</<?php echo $heading_tag; ?>>
    <br />
    <div id="site-description"><?php bloginfo( 'description' ); ?></div>

<div id="orb" style="display:none;">
<div class="startwrap">
<div class="start">
<!-- IF S_DISPLAY_SEARCH -->
	<div id="startsearch">
    <form method="get" id="search" action="<?php echo home_url(); ?>/">
	<input type="text" id="keywords" value="Search..." onfocus="if (this.value == 'Search...') {this.value = '';}" onblur="if (this.value == '') {this.value = 'Search...';}" name="s" />
	<input class="searchbutton" name="submit" type="image" src="<?php bloginfo('template_directory'); ?>/images/icon_textbox_search.gif" />
	</form>
	</div>
<!-- ENDIF -->
</div>
</div>
</div>

<div class="navorbwrap">
<a onclick="$('#orb').toggle()"><span class="navorb"></span></a>
</div>
    </td>
	<td class="midr" align="right" valign="top">

<div id="example" class="midlink">
<div id="search-box">
<form method="get" id="searchform" action="<?php echo home_url(); ?>/">
<input type="text" id="searchbox" value="Search..." style="opacity:0.8;filter:alpha(opacity=80)" onmouseover="this.style.opacity=1;this.filters.alpha.opacity=100" onmouseout="this.style.opacity=0.8;this.filters.alpha.opacity=80" onfocus="if (this.value == 'Search...') {this.value = '';}" onblur="if (this.value == '') {this.value = 'Search...';}" name="s" />
<input class="nb" name="submit" type="image" src="<?php bloginfo('template_directory'); ?>/images/search.png" align="absmiddle" />
</form>
</div>
</div>

      </td>
  </tr>
  </table>
    <table width="100%" border="0" align="center" cellpadding="0" cellspacing="0">
    <tr>
<td height="24" style="background: #06518A url('<?php bloginfo('template_directory'); ?>/images/navbarbg.png') no-repeat right top;">
<div id="navbarbg">
	<ul id="nav">
		<li><a href="<?php echo home_url(); ?>">Home</a></li>
        <?php wp_list_pages('depth=1&title_li=0&sort_column=menu_order'); ?>
	</ul>

<div class="navright">
<a onclick="$('#example').toggle()"><span class="navbutton"></span></a>
<span class="navtime">
<script type="text/javascript">
/* <![CDATA[ */ 

var a_p = "";
var d = new Date();
var curr_hour = d.getHours();
if (curr_hour < 12)
   {
   a_p = "AM";
   }
else
   {
   a_p = "PM";
   }
if (curr_hour == 0)
   {
   curr_hour = 12;
   }
if (curr_hour > 12)
   {
   curr_hour = curr_hour - 12;
   }

var curr_min = d.getMinutes();

curr_min = curr_min + "";

if (curr_min.length == 1)
   {
   curr_min = "0" + curr_min;
   }

document.write(curr_hour + ":" + curr_min + " " + a_p);

/* ]]> */ 
</script>
</span>
</div>
</div>
    </td>
  </tr>
  </table>
</td>
    <td class="mr"></td>
  </tr>
  <tr>
    <td class="bl"></td>
    <td class="bm"></td>
    <td class="br"></td>
  </tr>
</table>           

		</div><!-- #masthead -->
	</div><!-- #header -->

	<div id="main">
